Skip to contents

Core `Systems Ethology` Shiny platform acting as the central interactive wrapper modularizing age distributions, probability envelopes, runtime data interactions, and file downloads. Composes elements from `sysetholApp` and `downloadApp`.

Usage

ewingApp(title = "Systems Ethology")

ewingServer(id)

ewingInput(id)

ewingOutput(id)

Arguments

title

Application title

id

module ID string