Red Scale simulation initiation
redscale.RdSample simulation initiation setup.
Format
redscale is a data frame with the following columns
- DD
mean degree days to future event
- aphytis.feed
relative risk of being killed by an Aphytis that is feeding
- aphytis
relative risk of being killed by an Aphytis that is laying eggs
- comperiella
relative risk for comperiella
- encarsia
relative risk for encarsia
- gender
gender (only females modeled here)
- pch
plot character
- color
plot color
- stage
life stage of organism
Examples
data(redscale)