Organizes numerical nodes logically over explicit geometrical borders defined by `create_substrate` attributes.
Usage
# S3 method for class 'substrate'
autoplot(object, ...)
Arguments
- object
Data structure of type `substrate` mapped previously via abstract tridiagonal coordinates.
- ...
Additional graphical tracking arguments passing to generic rendering matrices.
Value
A `ggplot` visual abstraction of the Ewing network.