Envelope Plot App
envPlotApp.RdShiny application modules used strictly to render and wrap statistical envelope probability intervals generated natively by active `nsim > 1` discrete operations.
envPlotApp.RdShiny application modules used strictly to render and wrap statistical envelope probability intervals generated natively by active `nsim > 1` discrete operations.