Ewing App
ewingApp.RdCore `Systems Ethology` Shiny platform acting as the central interactive wrapper modularizing age distributions, probability envelopes, runtime data interactions, and file downloads. Composes elements from `sysetholApp` and `downloadApp`.