Systems Ethology App
sysetholApp.RdInteractive Systems Ethology platform orchestrating host-parasite individual-based simulations, age class distributions, hexagonal spatial substrate networks, variance envelopes, and input data tables.
Unified platform wrapper launching the Systems Ethology simulation application for any target ecosystem (e.g. `"default"`, `"isle_royale"`).